#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 profunctors
version:              5.6.3
visibility:           public
id:                   profunctors-5.6.3-6xnRR8Hc4jMAg82vUDmFP0
key:                  profunctors-5.6.3-6xnRR8Hc4jMAg82vUDmFP0
license:              BSD-3-Clause
copyright:            Copyright (C) 2011-2015 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            experimental
homepage:             http://github.com/ekmett/profunctors/
synopsis:             Profunctors
description:          Profunctors.
category:             Control, Categories
abi:                  f4bfeef0e66eea9db454f280504b3d7e
exposed:              True
exposed-modules:
    Data.Profunctor Data.Profunctor.Adjunction Data.Profunctor.Cayley
    Data.Profunctor.Choice Data.Profunctor.Closed
    Data.Profunctor.Composition Data.Profunctor.Mapping
    Data.Profunctor.Monad Data.Profunctor.Ran Data.Profunctor.Rep
    Data.Profunctor.Sieve Data.Profunctor.Strong
    Data.Profunctor.Traversing Data.Profunctor.Types
    Data.Profunctor.Unsafe Data.Profunctor.Yoneda

import-dirs:          /usr/lib/ghc-9.6.6/site-local/profunctors-5.6.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/profunctors-5.6.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/profunctors-5.6.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-profunctors
hs-libraries:         HSprofunctors-5.6.3-6xnRR8Hc4jMAg82vUDmFP0
depends:
    base-4.18.2.1 base-orphans-0.9.4-F93g79l8c15JRU0CelkMYu
    bifunctors-5.6.3-JxqVPFA87CgGZDQtN7CDR0
    comonad-5.0.10-80KFUfdCaIgF2M9aH8lBCl
    contravariant-1.5.6-DrebhAx4XwC59wq9S42cYg
    distributive-0.6.3-7aYPGPHhVXd4FJqU4bakPh
    tagged-0.8.10-9VJfLOM9ch68xR35ePL46j transformers-0.6.1.0

haddock-interfaces:   /usr/share/doc/haskell-profunctors/html/profunctors.haddock
haddock-html:         /usr/share/doc/haskell-profunctors/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

